Package: EpiEstim
Version: 2.2-5
Title: Estimate Time Varying Reproduction Numbers from Epidemic Curves
Authors@R: c(person("Anne", "Cori", email = "a.cori@imperial.ac.uk", role = c("aut", "cre"), comment = c(ORCID = "0000-0002-8443-9162")), 
  person("Simon", "Cauchemez", role = "ctb"),
  person("Neil M.", "Ferguson", role = "ctb", comment = c(ORCID = "0000-0002-1154-8093")),
  person("Christophe", "Fraser", role = "ctb", comment = c(ORCID = "0000-0003-2399-9657")),
  person("Elisabeth", "Dahlqwist", role = "ctb", comment = c(ORCID = "0000-0001-5797-6803")),
  person("P. Alex", "Demarsh", role = "ctb"),
  person("Thibaut", "Jombart", role = "ctb", comment = c(ORCID = "0000-0003-2226-8692")),
  person("Zhian N.", "Kamvar", role = "ctb", comment = c(ORCID = "0000-0003-1458-7108")),
  person("Justin", "Lessler", role = "ctb", comment = c(ORCID = "0000-0002-9741-8109")),
  person("Shikun", "Li", role = "ctb"),
  person("Jonathan A.", "Polonsky", role = "ctb", comment = c(ORCID = "0000-0002-8634-4255")),
  person("Jake", "Stockwin", role = "ctb"),
  person("Robin", "Thompson", role = "ctb", comment = c(ORCID = "0000-0001-8545-5212")),
  person("Rolina", "van Gaalen", role = "ctb")
  )
Maintainer: Anne Cori <a.cori@imperial.ac.uk>
Description: Tools to quantify transmissibility throughout
    an epidemic from the analysis of time series of incidence as described in
    Cori et al. (2013) <doi:10.1093/aje/kwt133> and Wallinga and Teunis (2004) 
    <doi:10.1093/aje/kwh255>.
URL: https://github.com/mrc-ide/EpiEstim
BugReports: https://github.com/mrc-ide/EpiEstim/issues
Depends: R (>= 2.10)
Imports: coarseDataTools (>= 0.6-4), stats, graphics, reshape2,
        ggplot2, gridExtra, fitdistrplus, coda, incidence (>= 1.7.0),
        scales, grDevices
Suggests: testthat, utils, vdiffr, covr, knitr, rmarkdown
License: GPL (>= 2)
LazyLoad: yes
Encoding: UTF-8
RoxygenNote: 7.3.2
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-06-11 08:23:42 UTC; acori
Author: Anne Cori [aut, cre] (ORCID: <https://orcid.org/0000-0002-8443-9162>),
  Simon Cauchemez [ctb],
  Neil M. Ferguson [ctb] (ORCID: <https://orcid.org/0000-0002-1154-8093>),
  Christophe Fraser [ctb] (ORCID:
    <https://orcid.org/0000-0003-2399-9657>),
  Elisabeth Dahlqwist [ctb] (ORCID:
    <https://orcid.org/0000-0001-5797-6803>),
  P. Alex Demarsh [ctb],
  Thibaut Jombart [ctb] (ORCID: <https://orcid.org/0000-0003-2226-8692>),
  Zhian N. Kamvar [ctb] (ORCID: <https://orcid.org/0000-0003-1458-7108>),
  Justin Lessler [ctb] (ORCID: <https://orcid.org/0000-0002-9741-8109>),
  Shikun Li [ctb],
  Jonathan A. Polonsky [ctb] (ORCID:
    <https://orcid.org/0000-0002-8634-4255>),
  Jake Stockwin [ctb],
  Robin Thompson [ctb] (ORCID: <https://orcid.org/0000-0001-8545-5212>),
  Rolina van Gaalen [ctb]
Repository: CRAN
Date/Publication: 2025-06-27 09:00:07 UTC
Built: R 4.3.3; ; 2025-06-27 10:26:11 UTC; unix
