# Generated by roxygen2: do not edit by hand

S3method(plot,estimate_R)
export(DiscrSI)
export(EstimateR)
export(OverallInfectivity)
export(WT)
export(check_cdt_samples_convergence)
export(coarse2estim)
export(discr_si)
export(estimate_R)
export(estimate_R_plots)
export(init_mcmc_params)
export(make_config)
export(make_mcmc_control)
export(overall_infectivity)
export(sample_posterior_R)
export(wallinga_teunis)
import(grid)
import(gridExtra)
import(reshape2)
importFrom(coarseDataTools,dic.fit.mcmc)
importFrom(coda,as.mcmc)
importFrom(coda,as.mcmc.list)
importFrom(coda,gelman.diag)
importFrom(fitdistrplus,fitdist)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_ribbon)
importFrom(ggplot2,geom_step)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,last_plot)
importFrom(ggplot2,lims)
importFrom(ggplot2,scale_colour_manual)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_linetype_manual)
importFrom(ggplot2,theme)
importFrom(ggplot2,xlab)
importFrom(ggplot2,xlim)
importFrom(ggplot2,ylab)
importFrom(ggplot2,ylim)
importFrom(grDevices,palette)
importFrom(graphics,plot)
importFrom(incidence,as.incidence)
importFrom(incidence,incidence)
importFrom(scales,alpha)
importFrom(stats,median)
importFrom(stats,pgamma)
importFrom(stats,plnorm)
importFrom(stats,pweibull)
importFrom(stats,qgamma)
importFrom(stats,qlnorm)
importFrom(stats,quantile)
importFrom(stats,qweibull)
importFrom(stats,rgamma)
importFrom(stats,rmultinom)
importFrom(stats,rnorm)
importFrom(stats,sd)
