# EpiEstim

<!-- badges: start -->
[![R build status](https://github.com/mrc-ide/EpiEstim/workflows/R-CMD-check/badge.svg)](https://github.com/mrc-ide/EpiEstim/actions)
[![Codecov test coverage](https://codecov.io/gh/annecori/EpiEstim/branch/master/graph/badge.svg)](https://app.codecov.io/gh/annecori/EpiEstim?branch=master)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3333654.svg)](https://doi.org/10.5281/zenodo.3333654)
<!-- badges: end -->

A tool to estimate time varying instantaneous reproduction number during epidemics

This tool is described in the following paper: 

A New Framework and Software to Estimate Time-Varying Reproduction Numbers During Epidemics
Anne Cori, Neil M. Ferguson, Christophe Fraser and Simon Cauchemez
American Journal of Epidemiology 2013.
